==> nextcloud-app-news-1%3A25.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/mk.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Непрочитани статии",
    "News" : "Новости",
    "Download" : "Преземи",
    "Close" : "Затвори",
    "Folder name" : "Име на папка",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Feed exists already!" : "Каналот веќе постои!",
    "New folder" : "Нова папка",
    "Credentials" : "Акредитиви",
    "Subscribe" : "Претплата",
    "Last job ran {relativeTime}." : "Последната процедура се изврши пред {relativeTime}.",
    "Move" : "Премести",
    "Share" : "Сподели",
    "Mark read" : "Означи како прочитано",
    "All articles" : "Сите статии",
    "Starred" : "Со ѕвезда",
    "Settings" : "Параметри",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Newest first" : "Новите прво",
    "Oldest first" : "Старите прво",
    "Mark unread" : "Означи како непрочитано",
    "by" : "од",
    "from" : "од",
    "Open website" : "Отвори вебсајт",
    "{num} months ago" : "пред {num} месеци",
    "Keyboard shortcut" : "Кратенка преку тастатура",
    "right" : "десно",
    "left" : "лево",
    "Refresh" : "Освежи",
    "Load next feed" : "Вчитај следен канал",
    "Shift" : "Shift",
    "Description" : "Опис",
    "Folder" : "Папка",
    "Go back" : "Назад",
    "Create" : "Создај",
    "Deleted feed" : "Избришан канал",
    "Open feed URL" : "Отвори URL на каналот",
    "Dismiss" : "Отфрли",
    "Collapse" : "Собери",
    "Subscriptions (OPML)" : "Претплати (OPML)",
    "Import" : "Увези",
    "Export" : "Извези",
    "Unread/Starred Articles" : "Непрочитани/Означени статии",
    "Error when importing: file does not contain valid JSON" : "Грешка при импортирање: датотеката не содржи валиден JSON",
    "Help" : "Помош",
    "Documentation" : "Документација",
    "Report a bug" : "Пријави грешка"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-news-1%3A25.2.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/mk.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Непрочитани статии",
    "News" : "Новости",
    "Download" : "Преземи",
    "Close" : "Затвори",
    "Folder name" : "Име на папка",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Feed exists already!" : "Каналот веќе постои!",
    "New folder" : "Нова папка",
    "Credentials" : "Акредитиви",
    "Subscribe" : "Претплата",
    "Last job ran {relativeTime}." : "Последната процедура се изврши пред {relativeTime}.",
    "Move" : "Премести",
    "Share" : "Сподели",
    "Mark read" : "Означи како прочитано",
    "All articles" : "Сите статии",
    "Starred" : "Со ѕвезда",
    "Settings" : "Параметри",
    "Documentation" : "Документација",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "Default" : "Предефиниран",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Newest first" : "Новите прво",
    "Oldest first" : "Старите прво",
    "Previous" : "Предходна",
    "Next" : "Следна",
    "Mark unread" : "Означи како непрочитано",
    "by" : "од",
    "from" : "од",
    "Open website" : "Отвори вебсајт",
    "{num} months ago" : "пред {num} месеци",
    "Not available" : "Недостапно",
    "Keyboard shortcut" : "Кратенка преку тастатура",
    "right" : "десно",
    "left" : "лево",
    "Refresh" : "Освежи",
    "Load next feed" : "Вчитај следен канал",
    "Shift" : "Shift",
    "Description" : "Опис",
    "Folder" : "Папка",
    "Go back" : "Назад",
    "Create" : "Создај",
    "Deleted feed" : "Избришан канал",
    "Open feed URL" : "Отвори URL на каналот",
    "Dismiss" : "Отфрли",
    "Collapse" : "Собери",
    "Subscriptions (OPML)" : "Претплати (OPML)",
    "Import" : "Увези",
    "Export" : "Извези",
    "Unread/Starred Articles" : "Непрочитани/Означени статии",
    "Error when importing: file does not contain valid JSON" : "Грешка при импортирање: датотеката не содржи валиден JSON",
    "Help" : "Помош",
    "Report a bug" : "Пријави грешка"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
